# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['google-stubs']

package_data = \
{'': ['*'],
 'google-stubs': ['ads/googleads/*',
                  'ads/googleads/interceptors/*',
                  'ads/googleads/v7/*',
                  'ads/googleads/v7/common/*',
                  'ads/googleads/v7/common/services/*',
                  'ads/googleads/v7/common/types/*',
                  'ads/googleads/v7/enums/*',
                  'ads/googleads/v7/enums/services/*',
                  'ads/googleads/v7/enums/types/*',
                  'ads/googleads/v7/errors/*',
                  'ads/googleads/v7/errors/services/*',
                  'ads/googleads/v7/errors/types/*',
                  'ads/googleads/v7/resources/*',
                  'ads/googleads/v7/resources/services/*',
                  'ads/googleads/v7/resources/types/*',
                  'ads/googleads/v7/services/*',
                  'ads/googleads/v7/services/services/*',
                  'ads/googleads/v7/services/services/account_budget_proposal_service/*',
                  'ads/googleads/v7/services/services/account_budget_proposal_service/transports/*',
                  'ads/googleads/v7/services/services/account_budget_service/*',
                  'ads/googleads/v7/services/services/account_budget_service/transports/*',
                  'ads/googleads/v7/services/services/account_link_service/*',
                  'ads/googleads/v7/services/services/account_link_service/transports/*',
                  'ads/googleads/v7/services/services/ad_group_ad_asset_view_service/*',
                  'ads/googleads/v7/services/services/ad_group_ad_asset_view_service/transports/*',
                  'ads/googleads/v7/services/services/ad_group_ad_label_service/*',
                  'ads/googleads/v7/services/services/ad_group_ad_label_service/transports/*',
                  'ads/googleads/v7/services/services/ad_group_ad_service/*',
                  'ads/googleads/v7/services/services/ad_group_ad_service/transports/*',
                  'ads/googleads/v7/services/services/ad_group_asset_service/*',
                  'ads/googleads/v7/services/services/ad_group_asset_service/transports/*',
                  'ads/googleads/v7/services/services/ad_group_audience_view_service/*',
                  'ads/googleads/v7/services/services/ad_group_audience_view_service/transports/*',
                  'ads/googleads/v7/services/services/ad_group_bid_modifier_service/*',
                  'ads/googleads/v7/services/services/ad_group_bid_modifier_service/transports/*',
                  'ads/googleads/v7/services/services/ad_group_criterion_label_service/*',
                  'ads/googleads/v7/services/services/ad_group_criterion_label_service/transports/*',
                  'ads/googleads/v7/services/services/ad_group_criterion_service/*',
                  'ads/googleads/v7/services/services/ad_group_criterion_service/transports/*',
                  'ads/googleads/v7/services/services/ad_group_criterion_simulation_service/*',
                  'ads/googleads/v7/services/services/ad_group_criterion_simulation_service/transports/*',
                  'ads/googleads/v7/services/services/ad_group_extension_setting_service/*',
                  'ads/googleads/v7/services/services/ad_group_extension_setting_service/transports/*',
                  'ads/googleads/v7/services/services/ad_group_feed_service/*',
                  'ads/googleads/v7/services/services/ad_group_feed_service/transports/*',
                  'ads/googleads/v7/services/services/ad_group_label_service/*',
                  'ads/googleads/v7/services/services/ad_group_label_service/transports/*',
                  'ads/googleads/v7/services/services/ad_group_service/*',
                  'ads/googleads/v7/services/services/ad_group_service/transports/*',
                  'ads/googleads/v7/services/services/ad_group_simulation_service/*',
                  'ads/googleads/v7/services/services/ad_group_simulation_service/transports/*',
                  'ads/googleads/v7/services/services/ad_parameter_service/*',
                  'ads/googleads/v7/services/services/ad_parameter_service/transports/*',
                  'ads/googleads/v7/services/services/ad_schedule_view_service/*',
                  'ads/googleads/v7/services/services/ad_schedule_view_service/transports/*',
                  'ads/googleads/v7/services/services/ad_service/*',
                  'ads/googleads/v7/services/services/ad_service/transports/*',
                  'ads/googleads/v7/services/services/age_range_view_service/*',
                  'ads/googleads/v7/services/services/age_range_view_service/transports/*',
                  'ads/googleads/v7/services/services/asset_service/*',
                  'ads/googleads/v7/services/services/asset_service/transports/*',
                  'ads/googleads/v7/services/services/batch_job_service/*',
                  'ads/googleads/v7/services/services/batch_job_service/transports/*',
                  'ads/googleads/v7/services/services/bidding_strategy_service/*',
                  'ads/googleads/v7/services/services/bidding_strategy_service/transports/*',
                  'ads/googleads/v7/services/services/bidding_strategy_simulation_service/*',
                  'ads/googleads/v7/services/services/bidding_strategy_simulation_service/transports/*',
                  'ads/googleads/v7/services/services/billing_setup_service/*',
                  'ads/googleads/v7/services/services/billing_setup_service/transports/*',
                  'ads/googleads/v7/services/services/campaign_asset_service/*',
                  'ads/googleads/v7/services/services/campaign_asset_service/transports/*',
                  'ads/googleads/v7/services/services/campaign_audience_view_service/*',
                  'ads/googleads/v7/services/services/campaign_audience_view_service/transports/*',
                  'ads/googleads/v7/services/services/campaign_bid_modifier_service/*',
                  'ads/googleads/v7/services/services/campaign_bid_modifier_service/transports/*',
                  'ads/googleads/v7/services/services/campaign_budget_service/*',
                  'ads/googleads/v7/services/services/campaign_budget_service/transports/*',
                  'ads/googleads/v7/services/services/campaign_criterion_service/*',
                  'ads/googleads/v7/services/services/campaign_criterion_service/transports/*',
                  'ads/googleads/v7/services/services/campaign_criterion_simulation_service/*',
                  'ads/googleads/v7/services/services/campaign_criterion_simulation_service/transports/*',
                  'ads/googleads/v7/services/services/campaign_draft_service/*',
                  'ads/googleads/v7/services/services/campaign_draft_service/transports/*',
                  'ads/googleads/v7/services/services/campaign_experiment_service/*',
                  'ads/googleads/v7/services/services/campaign_experiment_service/transports/*',
                  'ads/googleads/v7/services/services/campaign_extension_setting_service/*',
                  'ads/googleads/v7/services/services/campaign_extension_setting_service/transports/*',
                  'ads/googleads/v7/services/services/campaign_feed_service/*',
                  'ads/googleads/v7/services/services/campaign_feed_service/transports/*',
                  'ads/googleads/v7/services/services/campaign_label_service/*',
                  'ads/googleads/v7/services/services/campaign_label_service/transports/*',
                  'ads/googleads/v7/services/services/campaign_service/*',
                  'ads/googleads/v7/services/services/campaign_service/transports/*',
                  'ads/googleads/v7/services/services/campaign_shared_set_service/*',
                  'ads/googleads/v7/services/services/campaign_shared_set_service/transports/*',
                  'ads/googleads/v7/services/services/campaign_simulation_service/*',
                  'ads/googleads/v7/services/services/campaign_simulation_service/transports/*',
                  'ads/googleads/v7/services/services/carrier_constant_service/*',
                  'ads/googleads/v7/services/services/carrier_constant_service/transports/*',
                  'ads/googleads/v7/services/services/change_status_service/*',
                  'ads/googleads/v7/services/services/change_status_service/transports/*',
                  'ads/googleads/v7/services/services/click_view_service/*',
                  'ads/googleads/v7/services/services/click_view_service/transports/*',
                  'ads/googleads/v7/services/services/combined_audience_service/*',
                  'ads/googleads/v7/services/services/combined_audience_service/transports/*',
                  'ads/googleads/v7/services/services/conversion_action_service/*',
                  'ads/googleads/v7/services/services/conversion_action_service/transports/*',
                  'ads/googleads/v7/services/services/conversion_adjustment_upload_service/*',
                  'ads/googleads/v7/services/services/conversion_adjustment_upload_service/transports/*',
                  'ads/googleads/v7/services/services/conversion_custom_variable_service/*',
                  'ads/googleads/v7/services/services/conversion_custom_variable_service/transports/*',
                  'ads/googleads/v7/services/services/conversion_upload_service/*',
                  'ads/googleads/v7/services/services/conversion_upload_service/transports/*',
                  'ads/googleads/v7/services/services/currency_constant_service/*',
                  'ads/googleads/v7/services/services/currency_constant_service/transports/*',
                  'ads/googleads/v7/services/services/custom_audience_service/*',
                  'ads/googleads/v7/services/services/custom_audience_service/transports/*',
                  'ads/googleads/v7/services/services/custom_interest_service/*',
                  'ads/googleads/v7/services/services/custom_interest_service/transports/*',
                  'ads/googleads/v7/services/services/customer_asset_service/*',
                  'ads/googleads/v7/services/services/customer_asset_service/transports/*',
                  'ads/googleads/v7/services/services/customer_client_link_service/*',
                  'ads/googleads/v7/services/services/customer_client_link_service/transports/*',
                  'ads/googleads/v7/services/services/customer_client_service/*',
                  'ads/googleads/v7/services/services/customer_client_service/transports/*',
                  'ads/googleads/v7/services/services/customer_extension_setting_service/*',
                  'ads/googleads/v7/services/services/customer_extension_setting_service/transports/*',
                  'ads/googleads/v7/services/services/customer_feed_service/*',
                  'ads/googleads/v7/services/services/customer_feed_service/transports/*',
                  'ads/googleads/v7/services/services/customer_label_service/*',
                  'ads/googleads/v7/services/services/customer_label_service/transports/*',
                  'ads/googleads/v7/services/services/customer_manager_link_service/*',
                  'ads/googleads/v7/services/services/customer_manager_link_service/transports/*',
                  'ads/googleads/v7/services/services/customer_negative_criterion_service/*',
                  'ads/googleads/v7/services/services/customer_negative_criterion_service/transports/*',
                  'ads/googleads/v7/services/services/customer_service/*',
                  'ads/googleads/v7/services/services/customer_service/transports/*',
                  'ads/googleads/v7/services/services/customer_user_access_invitation_service/*',
                  'ads/googleads/v7/services/services/customer_user_access_invitation_service/transports/*',
                  'ads/googleads/v7/services/services/customer_user_access_service/*',
                  'ads/googleads/v7/services/services/customer_user_access_service/transports/*',
                  'ads/googleads/v7/services/services/detail_placement_view_service/*',
                  'ads/googleads/v7/services/services/detail_placement_view_service/transports/*',
                  'ads/googleads/v7/services/services/display_keyword_view_service/*',
                  'ads/googleads/v7/services/services/display_keyword_view_service/transports/*',
                  'ads/googleads/v7/services/services/distance_view_service/*',
                  'ads/googleads/v7/services/services/distance_view_service/transports/*',
                  'ads/googleads/v7/services/services/domain_category_service/*',
                  'ads/googleads/v7/services/services/domain_category_service/transports/*',
                  'ads/googleads/v7/services/services/dynamic_search_ads_search_term_view_service/*',
                  'ads/googleads/v7/services/services/dynamic_search_ads_search_term_view_service/transports/*',
                  'ads/googleads/v7/services/services/expanded_landing_page_view_service/*',
                  'ads/googleads/v7/services/services/expanded_landing_page_view_service/transports/*',
                  'ads/googleads/v7/services/services/extension_feed_item_service/*',
                  'ads/googleads/v7/services/services/extension_feed_item_service/transports/*',
                  'ads/googleads/v7/services/services/feed_item_service/*',
                  'ads/googleads/v7/services/services/feed_item_service/transports/*',
                  'ads/googleads/v7/services/services/feed_item_set_link_service/*',
                  'ads/googleads/v7/services/services/feed_item_set_link_service/transports/*',
                  'ads/googleads/v7/services/services/feed_item_set_service/*',
                  'ads/googleads/v7/services/services/feed_item_set_service/transports/*',
                  'ads/googleads/v7/services/services/feed_item_target_service/*',
                  'ads/googleads/v7/services/services/feed_item_target_service/transports/*',
                  'ads/googleads/v7/services/services/feed_mapping_service/*',
                  'ads/googleads/v7/services/services/feed_mapping_service/transports/*',
                  'ads/googleads/v7/services/services/feed_placeholder_view_service/*',
                  'ads/googleads/v7/services/services/feed_placeholder_view_service/transports/*',
                  'ads/googleads/v7/services/services/feed_service/*',
                  'ads/googleads/v7/services/services/feed_service/transports/*',
                  'ads/googleads/v7/services/services/gender_view_service/*',
                  'ads/googleads/v7/services/services/gender_view_service/transports/*',
                  'ads/googleads/v7/services/services/geo_target_constant_service/*',
                  'ads/googleads/v7/services/services/geo_target_constant_service/transports/*',
                  'ads/googleads/v7/services/services/geographic_view_service/*',
                  'ads/googleads/v7/services/services/geographic_view_service/transports/*',
                  'ads/googleads/v7/services/services/google_ads_field_service/*',
                  'ads/googleads/v7/services/services/google_ads_field_service/transports/*',
                  'ads/googleads/v7/services/services/google_ads_service/*',
                  'ads/googleads/v7/services/services/google_ads_service/transports/*',
                  'ads/googleads/v7/services/services/group_placement_view_service/*',
                  'ads/googleads/v7/services/services/group_placement_view_service/transports/*',
                  'ads/googleads/v7/services/services/hotel_group_view_service/*',
                  'ads/googleads/v7/services/services/hotel_group_view_service/transports/*',
                  'ads/googleads/v7/services/services/hotel_performance_view_service/*',
                  'ads/googleads/v7/services/services/hotel_performance_view_service/transports/*',
                  'ads/googleads/v7/services/services/income_range_view_service/*',
                  'ads/googleads/v7/services/services/income_range_view_service/transports/*',
                  'ads/googleads/v7/services/services/invoice_service/*',
                  'ads/googleads/v7/services/services/invoice_service/transports/*',
                  'ads/googleads/v7/services/services/keyword_plan_ad_group_keyword_service/*',
                  'ads/googleads/v7/services/services/keyword_plan_ad_group_keyword_service/transports/*',
                  'ads/googleads/v7/services/services/keyword_plan_ad_group_service/*',
                  'ads/googleads/v7/services/services/keyword_plan_ad_group_service/transports/*',
                  'ads/googleads/v7/services/services/keyword_plan_campaign_keyword_service/*',
                  'ads/googleads/v7/services/services/keyword_plan_campaign_keyword_service/transports/*',
                  'ads/googleads/v7/services/services/keyword_plan_campaign_service/*',
                  'ads/googleads/v7/services/services/keyword_plan_campaign_service/transports/*',
                  'ads/googleads/v7/services/services/keyword_plan_idea_service/*',
                  'ads/googleads/v7/services/services/keyword_plan_idea_service/transports/*',
                  'ads/googleads/v7/services/services/keyword_plan_service/*',
                  'ads/googleads/v7/services/services/keyword_plan_service/transports/*',
                  'ads/googleads/v7/services/services/keyword_view_service/*',
                  'ads/googleads/v7/services/services/keyword_view_service/transports/*',
                  'ads/googleads/v7/services/services/label_service/*',
                  'ads/googleads/v7/services/services/label_service/transports/*',
                  'ads/googleads/v7/services/services/landing_page_view_service/*',
                  'ads/googleads/v7/services/services/landing_page_view_service/transports/*',
                  'ads/googleads/v7/services/services/language_constant_service/*',
                  'ads/googleads/v7/services/services/language_constant_service/transports/*',
                  'ads/googleads/v7/services/services/life_event_service/*',
                  'ads/googleads/v7/services/services/life_event_service/transports/*',
                  'ads/googleads/v7/services/services/location_view_service/*',
                  'ads/googleads/v7/services/services/location_view_service/transports/*',
                  'ads/googleads/v7/services/services/managed_placement_view_service/*',
                  'ads/googleads/v7/services/services/managed_placement_view_service/transports/*',
                  'ads/googleads/v7/services/services/media_file_service/*',
                  'ads/googleads/v7/services/services/media_file_service/transports/*',
                  'ads/googleads/v7/services/services/merchant_center_link_service/*',
                  'ads/googleads/v7/services/services/merchant_center_link_service/transports/*',
                  'ads/googleads/v7/services/services/mobile_app_category_constant_service/*',
                  'ads/googleads/v7/services/services/mobile_app_category_constant_service/transports/*',
                  'ads/googleads/v7/services/services/mobile_device_constant_service/*',
                  'ads/googleads/v7/services/services/mobile_device_constant_service/transports/*',
                  'ads/googleads/v7/services/services/offline_user_data_job_service/*',
                  'ads/googleads/v7/services/services/offline_user_data_job_service/transports/*',
                  'ads/googleads/v7/services/services/operating_system_version_constant_service/*',
                  'ads/googleads/v7/services/services/operating_system_version_constant_service/transports/*',
                  'ads/googleads/v7/services/services/paid_organic_search_term_view_service/*',
                  'ads/googleads/v7/services/services/paid_organic_search_term_view_service/transports/*',
                  'ads/googleads/v7/services/services/parental_status_view_service/*',
                  'ads/googleads/v7/services/services/parental_status_view_service/transports/*',
                  'ads/googleads/v7/services/services/payments_account_service/*',
                  'ads/googleads/v7/services/services/payments_account_service/transports/*',
                  'ads/googleads/v7/services/services/product_bidding_category_constant_service/*',
                  'ads/googleads/v7/services/services/product_bidding_category_constant_service/transports/*',
                  'ads/googleads/v7/services/services/product_group_view_service/*',
                  'ads/googleads/v7/services/services/product_group_view_service/transports/*',
                  'ads/googleads/v7/services/services/reach_plan_service/*',
                  'ads/googleads/v7/services/services/reach_plan_service/transports/*',
                  'ads/googleads/v7/services/services/recommendation_service/*',
                  'ads/googleads/v7/services/services/recommendation_service/transports/*',
                  'ads/googleads/v7/services/services/remarketing_action_service/*',
                  'ads/googleads/v7/services/services/remarketing_action_service/transports/*',
                  'ads/googleads/v7/services/services/search_term_view_service/*',
                  'ads/googleads/v7/services/services/search_term_view_service/transports/*',
                  'ads/googleads/v7/services/services/shared_criterion_service/*',
                  'ads/googleads/v7/services/services/shared_criterion_service/transports/*',
                  'ads/googleads/v7/services/services/shared_set_service/*',
                  'ads/googleads/v7/services/services/shared_set_service/transports/*',
                  'ads/googleads/v7/services/services/shopping_performance_view_service/*',
                  'ads/googleads/v7/services/services/shopping_performance_view_service/transports/*',
                  'ads/googleads/v7/services/services/third_party_app_analytics_link_service/*',
                  'ads/googleads/v7/services/services/third_party_app_analytics_link_service/transports/*',
                  'ads/googleads/v7/services/services/topic_constant_service/*',
                  'ads/googleads/v7/services/services/topic_constant_service/transports/*',
                  'ads/googleads/v7/services/services/topic_view_service/*',
                  'ads/googleads/v7/services/services/topic_view_service/transports/*',
                  'ads/googleads/v7/services/services/user_data_service/*',
                  'ads/googleads/v7/services/services/user_data_service/transports/*',
                  'ads/googleads/v7/services/services/user_interest_service/*',
                  'ads/googleads/v7/services/services/user_interest_service/transports/*',
                  'ads/googleads/v7/services/services/user_list_service/*',
                  'ads/googleads/v7/services/services/user_list_service/transports/*',
                  'ads/googleads/v7/services/services/user_location_view_service/*',
                  'ads/googleads/v7/services/services/user_location_view_service/transports/*',
                  'ads/googleads/v7/services/services/video_service/*',
                  'ads/googleads/v7/services/services/video_service/transports/*',
                  'ads/googleads/v7/services/services/webpage_view_service/*',
                  'ads/googleads/v7/services/services/webpage_view_service/transports/*',
                  'ads/googleads/v7/services/types/*',
                  'ads/googleads/v7/types/*',
                  'ads/googleads/v8/*',
                  'ads/googleads/v8/common/*',
                  'ads/googleads/v8/common/services/*',
                  'ads/googleads/v8/common/types/*',
                  'ads/googleads/v8/enums/*',
                  'ads/googleads/v8/enums/services/*',
                  'ads/googleads/v8/enums/types/*',
                  'ads/googleads/v8/errors/*',
                  'ads/googleads/v8/errors/services/*',
                  'ads/googleads/v8/errors/types/*',
                  'ads/googleads/v8/resources/*',
                  'ads/googleads/v8/resources/services/*',
                  'ads/googleads/v8/resources/types/*',
                  'ads/googleads/v8/services/*',
                  'ads/googleads/v8/services/services/*',
                  'ads/googleads/v8/services/services/accessible_bidding_strategy_service/*',
                  'ads/googleads/v8/services/services/accessible_bidding_strategy_service/transports/*',
                  'ads/googleads/v8/services/services/account_budget_proposal_service/*',
                  'ads/googleads/v8/services/services/account_budget_proposal_service/transports/*',
                  'ads/googleads/v8/services/services/account_budget_service/*',
                  'ads/googleads/v8/services/services/account_budget_service/transports/*',
                  'ads/googleads/v8/services/services/account_link_service/*',
                  'ads/googleads/v8/services/services/account_link_service/transports/*',
                  'ads/googleads/v8/services/services/ad_group_ad_asset_view_service/*',
                  'ads/googleads/v8/services/services/ad_group_ad_asset_view_service/transports/*',
                  'ads/googleads/v8/services/services/ad_group_ad_label_service/*',
                  'ads/googleads/v8/services/services/ad_group_ad_label_service/transports/*',
                  'ads/googleads/v8/services/services/ad_group_ad_service/*',
                  'ads/googleads/v8/services/services/ad_group_ad_service/transports/*',
                  'ads/googleads/v8/services/services/ad_group_asset_service/*',
                  'ads/googleads/v8/services/services/ad_group_asset_service/transports/*',
                  'ads/googleads/v8/services/services/ad_group_audience_view_service/*',
                  'ads/googleads/v8/services/services/ad_group_audience_view_service/transports/*',
                  'ads/googleads/v8/services/services/ad_group_bid_modifier_service/*',
                  'ads/googleads/v8/services/services/ad_group_bid_modifier_service/transports/*',
                  'ads/googleads/v8/services/services/ad_group_criterion_label_service/*',
                  'ads/googleads/v8/services/services/ad_group_criterion_label_service/transports/*',
                  'ads/googleads/v8/services/services/ad_group_criterion_service/*',
                  'ads/googleads/v8/services/services/ad_group_criterion_service/transports/*',
                  'ads/googleads/v8/services/services/ad_group_criterion_simulation_service/*',
                  'ads/googleads/v8/services/services/ad_group_criterion_simulation_service/transports/*',
                  'ads/googleads/v8/services/services/ad_group_extension_setting_service/*',
                  'ads/googleads/v8/services/services/ad_group_extension_setting_service/transports/*',
                  'ads/googleads/v8/services/services/ad_group_feed_service/*',
                  'ads/googleads/v8/services/services/ad_group_feed_service/transports/*',
                  'ads/googleads/v8/services/services/ad_group_label_service/*',
                  'ads/googleads/v8/services/services/ad_group_label_service/transports/*',
                  'ads/googleads/v8/services/services/ad_group_service/*',
                  'ads/googleads/v8/services/services/ad_group_service/transports/*',
                  'ads/googleads/v8/services/services/ad_group_simulation_service/*',
                  'ads/googleads/v8/services/services/ad_group_simulation_service/transports/*',
                  'ads/googleads/v8/services/services/ad_parameter_service/*',
                  'ads/googleads/v8/services/services/ad_parameter_service/transports/*',
                  'ads/googleads/v8/services/services/ad_schedule_view_service/*',
                  'ads/googleads/v8/services/services/ad_schedule_view_service/transports/*',
                  'ads/googleads/v8/services/services/ad_service/*',
                  'ads/googleads/v8/services/services/ad_service/transports/*',
                  'ads/googleads/v8/services/services/age_range_view_service/*',
                  'ads/googleads/v8/services/services/age_range_view_service/transports/*',
                  'ads/googleads/v8/services/services/asset_field_type_view_service/*',
                  'ads/googleads/v8/services/services/asset_field_type_view_service/transports/*',
                  'ads/googleads/v8/services/services/asset_service/*',
                  'ads/googleads/v8/services/services/asset_service/transports/*',
                  'ads/googleads/v8/services/services/batch_job_service/*',
                  'ads/googleads/v8/services/services/batch_job_service/transports/*',
                  'ads/googleads/v8/services/services/bidding_data_exclusion_service/*',
                  'ads/googleads/v8/services/services/bidding_data_exclusion_service/transports/*',
                  'ads/googleads/v8/services/services/bidding_seasonality_adjustment_service/*',
                  'ads/googleads/v8/services/services/bidding_seasonality_adjustment_service/transports/*',
                  'ads/googleads/v8/services/services/bidding_strategy_service/*',
                  'ads/googleads/v8/services/services/bidding_strategy_service/transports/*',
                  'ads/googleads/v8/services/services/bidding_strategy_simulation_service/*',
                  'ads/googleads/v8/services/services/bidding_strategy_simulation_service/transports/*',
                  'ads/googleads/v8/services/services/billing_setup_service/*',
                  'ads/googleads/v8/services/services/billing_setup_service/transports/*',
                  'ads/googleads/v8/services/services/campaign_asset_service/*',
                  'ads/googleads/v8/services/services/campaign_asset_service/transports/*',
                  'ads/googleads/v8/services/services/campaign_audience_view_service/*',
                  'ads/googleads/v8/services/services/campaign_audience_view_service/transports/*',
                  'ads/googleads/v8/services/services/campaign_bid_modifier_service/*',
                  'ads/googleads/v8/services/services/campaign_bid_modifier_service/transports/*',
                  'ads/googleads/v8/services/services/campaign_budget_service/*',
                  'ads/googleads/v8/services/services/campaign_budget_service/transports/*',
                  'ads/googleads/v8/services/services/campaign_criterion_service/*',
                  'ads/googleads/v8/services/services/campaign_criterion_service/transports/*',
                  'ads/googleads/v8/services/services/campaign_criterion_simulation_service/*',
                  'ads/googleads/v8/services/services/campaign_criterion_simulation_service/transports/*',
                  'ads/googleads/v8/services/services/campaign_draft_service/*',
                  'ads/googleads/v8/services/services/campaign_draft_service/transports/*',
                  'ads/googleads/v8/services/services/campaign_experiment_service/*',
                  'ads/googleads/v8/services/services/campaign_experiment_service/transports/*',
                  'ads/googleads/v8/services/services/campaign_extension_setting_service/*',
                  'ads/googleads/v8/services/services/campaign_extension_setting_service/transports/*',
                  'ads/googleads/v8/services/services/campaign_feed_service/*',
                  'ads/googleads/v8/services/services/campaign_feed_service/transports/*',
                  'ads/googleads/v8/services/services/campaign_label_service/*',
                  'ads/googleads/v8/services/services/campaign_label_service/transports/*',
                  'ads/googleads/v8/services/services/campaign_service/*',
                  'ads/googleads/v8/services/services/campaign_service/transports/*',
                  'ads/googleads/v8/services/services/campaign_shared_set_service/*',
                  'ads/googleads/v8/services/services/campaign_shared_set_service/transports/*',
                  'ads/googleads/v8/services/services/campaign_simulation_service/*',
                  'ads/googleads/v8/services/services/campaign_simulation_service/transports/*',
                  'ads/googleads/v8/services/services/carrier_constant_service/*',
                  'ads/googleads/v8/services/services/carrier_constant_service/transports/*',
                  'ads/googleads/v8/services/services/change_status_service/*',
                  'ads/googleads/v8/services/services/change_status_service/transports/*',
                  'ads/googleads/v8/services/services/click_view_service/*',
                  'ads/googleads/v8/services/services/click_view_service/transports/*',
                  'ads/googleads/v8/services/services/combined_audience_service/*',
                  'ads/googleads/v8/services/services/combined_audience_service/transports/*',
                  'ads/googleads/v8/services/services/conversion_action_service/*',
                  'ads/googleads/v8/services/services/conversion_action_service/transports/*',
                  'ads/googleads/v8/services/services/conversion_adjustment_upload_service/*',
                  'ads/googleads/v8/services/services/conversion_adjustment_upload_service/transports/*',
                  'ads/googleads/v8/services/services/conversion_custom_variable_service/*',
                  'ads/googleads/v8/services/services/conversion_custom_variable_service/transports/*',
                  'ads/googleads/v8/services/services/conversion_upload_service/*',
                  'ads/googleads/v8/services/services/conversion_upload_service/transports/*',
                  'ads/googleads/v8/services/services/conversion_value_rule_service/*',
                  'ads/googleads/v8/services/services/conversion_value_rule_service/transports/*',
                  'ads/googleads/v8/services/services/conversion_value_rule_set_service/*',
                  'ads/googleads/v8/services/services/conversion_value_rule_set_service/transports/*',
                  'ads/googleads/v8/services/services/currency_constant_service/*',
                  'ads/googleads/v8/services/services/currency_constant_service/transports/*',
                  'ads/googleads/v8/services/services/custom_audience_service/*',
                  'ads/googleads/v8/services/services/custom_audience_service/transports/*',
                  'ads/googleads/v8/services/services/custom_interest_service/*',
                  'ads/googleads/v8/services/services/custom_interest_service/transports/*',
                  'ads/googleads/v8/services/services/customer_asset_service/*',
                  'ads/googleads/v8/services/services/customer_asset_service/transports/*',
                  'ads/googleads/v8/services/services/customer_client_link_service/*',
                  'ads/googleads/v8/services/services/customer_client_link_service/transports/*',
                  'ads/googleads/v8/services/services/customer_client_service/*',
                  'ads/googleads/v8/services/services/customer_client_service/transports/*',
                  'ads/googleads/v8/services/services/customer_extension_setting_service/*',
                  'ads/googleads/v8/services/services/customer_extension_setting_service/transports/*',
                  'ads/googleads/v8/services/services/customer_feed_service/*',
                  'ads/googleads/v8/services/services/customer_feed_service/transports/*',
                  'ads/googleads/v8/services/services/customer_label_service/*',
                  'ads/googleads/v8/services/services/customer_label_service/transports/*',
                  'ads/googleads/v8/services/services/customer_manager_link_service/*',
                  'ads/googleads/v8/services/services/customer_manager_link_service/transports/*',
                  'ads/googleads/v8/services/services/customer_negative_criterion_service/*',
                  'ads/googleads/v8/services/services/customer_negative_criterion_service/transports/*',
                  'ads/googleads/v8/services/services/customer_service/*',
                  'ads/googleads/v8/services/services/customer_service/transports/*',
                  'ads/googleads/v8/services/services/customer_user_access_invitation_service/*',
                  'ads/googleads/v8/services/services/customer_user_access_invitation_service/transports/*',
                  'ads/googleads/v8/services/services/customer_user_access_service/*',
                  'ads/googleads/v8/services/services/customer_user_access_service/transports/*',
                  'ads/googleads/v8/services/services/detail_placement_view_service/*',
                  'ads/googleads/v8/services/services/detail_placement_view_service/transports/*',
                  'ads/googleads/v8/services/services/detailed_demographic_service/*',
                  'ads/googleads/v8/services/services/detailed_demographic_service/transports/*',
                  'ads/googleads/v8/services/services/display_keyword_view_service/*',
                  'ads/googleads/v8/services/services/display_keyword_view_service/transports/*',
                  'ads/googleads/v8/services/services/distance_view_service/*',
                  'ads/googleads/v8/services/services/distance_view_service/transports/*',
                  'ads/googleads/v8/services/services/domain_category_service/*',
                  'ads/googleads/v8/services/services/domain_category_service/transports/*',
                  'ads/googleads/v8/services/services/dynamic_search_ads_search_term_view_service/*',
                  'ads/googleads/v8/services/services/dynamic_search_ads_search_term_view_service/transports/*',
                  'ads/googleads/v8/services/services/expanded_landing_page_view_service/*',
                  'ads/googleads/v8/services/services/expanded_landing_page_view_service/transports/*',
                  'ads/googleads/v8/services/services/extension_feed_item_service/*',
                  'ads/googleads/v8/services/services/extension_feed_item_service/transports/*',
                  'ads/googleads/v8/services/services/feed_item_service/*',
                  'ads/googleads/v8/services/services/feed_item_service/transports/*',
                  'ads/googleads/v8/services/services/feed_item_set_link_service/*',
                  'ads/googleads/v8/services/services/feed_item_set_link_service/transports/*',
                  'ads/googleads/v8/services/services/feed_item_set_service/*',
                  'ads/googleads/v8/services/services/feed_item_set_service/transports/*',
                  'ads/googleads/v8/services/services/feed_item_target_service/*',
                  'ads/googleads/v8/services/services/feed_item_target_service/transports/*',
                  'ads/googleads/v8/services/services/feed_mapping_service/*',
                  'ads/googleads/v8/services/services/feed_mapping_service/transports/*',
                  'ads/googleads/v8/services/services/feed_placeholder_view_service/*',
                  'ads/googleads/v8/services/services/feed_placeholder_view_service/transports/*',
                  'ads/googleads/v8/services/services/feed_service/*',
                  'ads/googleads/v8/services/services/feed_service/transports/*',
                  'ads/googleads/v8/services/services/gender_view_service/*',
                  'ads/googleads/v8/services/services/gender_view_service/transports/*',
                  'ads/googleads/v8/services/services/geo_target_constant_service/*',
                  'ads/googleads/v8/services/services/geo_target_constant_service/transports/*',
                  'ads/googleads/v8/services/services/geographic_view_service/*',
                  'ads/googleads/v8/services/services/geographic_view_service/transports/*',
                  'ads/googleads/v8/services/services/google_ads_field_service/*',
                  'ads/googleads/v8/services/services/google_ads_field_service/transports/*',
                  'ads/googleads/v8/services/services/google_ads_service/*',
                  'ads/googleads/v8/services/services/google_ads_service/transports/*',
                  'ads/googleads/v8/services/services/group_placement_view_service/*',
                  'ads/googleads/v8/services/services/group_placement_view_service/transports/*',
                  'ads/googleads/v8/services/services/hotel_group_view_service/*',
                  'ads/googleads/v8/services/services/hotel_group_view_service/transports/*',
                  'ads/googleads/v8/services/services/hotel_performance_view_service/*',
                  'ads/googleads/v8/services/services/hotel_performance_view_service/transports/*',
                  'ads/googleads/v8/services/services/income_range_view_service/*',
                  'ads/googleads/v8/services/services/income_range_view_service/transports/*',
                  'ads/googleads/v8/services/services/invoice_service/*',
                  'ads/googleads/v8/services/services/invoice_service/transports/*',
                  'ads/googleads/v8/services/services/keyword_plan_ad_group_keyword_service/*',
                  'ads/googleads/v8/services/services/keyword_plan_ad_group_keyword_service/transports/*',
                  'ads/googleads/v8/services/services/keyword_plan_ad_group_service/*',
                  'ads/googleads/v8/services/services/keyword_plan_ad_group_service/transports/*',
                  'ads/googleads/v8/services/services/keyword_plan_campaign_keyword_service/*',
                  'ads/googleads/v8/services/services/keyword_plan_campaign_keyword_service/transports/*',
                  'ads/googleads/v8/services/services/keyword_plan_campaign_service/*',
                  'ads/googleads/v8/services/services/keyword_plan_campaign_service/transports/*',
                  'ads/googleads/v8/services/services/keyword_plan_idea_service/*',
                  'ads/googleads/v8/services/services/keyword_plan_idea_service/transports/*',
                  'ads/googleads/v8/services/services/keyword_plan_service/*',
                  'ads/googleads/v8/services/services/keyword_plan_service/transports/*',
                  'ads/googleads/v8/services/services/keyword_theme_constant_service/*',
                  'ads/googleads/v8/services/services/keyword_theme_constant_service/transports/*',
                  'ads/googleads/v8/services/services/keyword_view_service/*',
                  'ads/googleads/v8/services/services/keyword_view_service/transports/*',
                  'ads/googleads/v8/services/services/label_service/*',
                  'ads/googleads/v8/services/services/label_service/transports/*',
                  'ads/googleads/v8/services/services/landing_page_view_service/*',
                  'ads/googleads/v8/services/services/landing_page_view_service/transports/*',
                  'ads/googleads/v8/services/services/language_constant_service/*',
                  'ads/googleads/v8/services/services/language_constant_service/transports/*',
                  'ads/googleads/v8/services/services/life_event_service/*',
                  'ads/googleads/v8/services/services/life_event_service/transports/*',
                  'ads/googleads/v8/services/services/location_view_service/*',
                  'ads/googleads/v8/services/services/location_view_service/transports/*',
                  'ads/googleads/v8/services/services/managed_placement_view_service/*',
                  'ads/googleads/v8/services/services/managed_placement_view_service/transports/*',
                  'ads/googleads/v8/services/services/media_file_service/*',
                  'ads/googleads/v8/services/services/media_file_service/transports/*',
                  'ads/googleads/v8/services/services/merchant_center_link_service/*',
                  'ads/googleads/v8/services/services/merchant_center_link_service/transports/*',
                  'ads/googleads/v8/services/services/mobile_app_category_constant_service/*',
                  'ads/googleads/v8/services/services/mobile_app_category_constant_service/transports/*',
                  'ads/googleads/v8/services/services/mobile_device_constant_service/*',
                  'ads/googleads/v8/services/services/mobile_device_constant_service/transports/*',
                  'ads/googleads/v8/services/services/offline_user_data_job_service/*',
                  'ads/googleads/v8/services/services/offline_user_data_job_service/transports/*',
                  'ads/googleads/v8/services/services/operating_system_version_constant_service/*',
                  'ads/googleads/v8/services/services/operating_system_version_constant_service/transports/*',
                  'ads/googleads/v8/services/services/paid_organic_search_term_view_service/*',
                  'ads/googleads/v8/services/services/paid_organic_search_term_view_service/transports/*',
                  'ads/googleads/v8/services/services/parental_status_view_service/*',
                  'ads/googleads/v8/services/services/parental_status_view_service/transports/*',
                  'ads/googleads/v8/services/services/payments_account_service/*',
                  'ads/googleads/v8/services/services/payments_account_service/transports/*',
                  'ads/googleads/v8/services/services/product_bidding_category_constant_service/*',
                  'ads/googleads/v8/services/services/product_bidding_category_constant_service/transports/*',
                  'ads/googleads/v8/services/services/product_group_view_service/*',
                  'ads/googleads/v8/services/services/product_group_view_service/transports/*',
                  'ads/googleads/v8/services/services/reach_plan_service/*',
                  'ads/googleads/v8/services/services/reach_plan_service/transports/*',
                  'ads/googleads/v8/services/services/recommendation_service/*',
                  'ads/googleads/v8/services/services/recommendation_service/transports/*',
                  'ads/googleads/v8/services/services/remarketing_action_service/*',
                  'ads/googleads/v8/services/services/remarketing_action_service/transports/*',
                  'ads/googleads/v8/services/services/search_term_view_service/*',
                  'ads/googleads/v8/services/services/search_term_view_service/transports/*',
                  'ads/googleads/v8/services/services/shared_criterion_service/*',
                  'ads/googleads/v8/services/services/shared_criterion_service/transports/*',
                  'ads/googleads/v8/services/services/shared_set_service/*',
                  'ads/googleads/v8/services/services/shared_set_service/transports/*',
                  'ads/googleads/v8/services/services/shopping_performance_view_service/*',
                  'ads/googleads/v8/services/services/shopping_performance_view_service/transports/*',
                  'ads/googleads/v8/services/services/smart_campaign_search_term_view_service/*',
                  'ads/googleads/v8/services/services/smart_campaign_search_term_view_service/transports/*',
                  'ads/googleads/v8/services/services/smart_campaign_setting_service/*',
                  'ads/googleads/v8/services/services/smart_campaign_setting_service/transports/*',
                  'ads/googleads/v8/services/services/smart_campaign_suggest_service/*',
                  'ads/googleads/v8/services/services/smart_campaign_suggest_service/transports/*',
                  'ads/googleads/v8/services/services/third_party_app_analytics_link_service/*',
                  'ads/googleads/v8/services/services/third_party_app_analytics_link_service/transports/*',
                  'ads/googleads/v8/services/services/topic_constant_service/*',
                  'ads/googleads/v8/services/services/topic_constant_service/transports/*',
                  'ads/googleads/v8/services/services/topic_view_service/*',
                  'ads/googleads/v8/services/services/topic_view_service/transports/*',
                  'ads/googleads/v8/services/services/user_data_service/*',
                  'ads/googleads/v8/services/services/user_data_service/transports/*',
                  'ads/googleads/v8/services/services/user_interest_service/*',
                  'ads/googleads/v8/services/services/user_interest_service/transports/*',
                  'ads/googleads/v8/services/services/user_list_service/*',
                  'ads/googleads/v8/services/services/user_list_service/transports/*',
                  'ads/googleads/v8/services/services/user_location_view_service/*',
                  'ads/googleads/v8/services/services/user_location_view_service/transports/*',
                  'ads/googleads/v8/services/services/video_service/*',
                  'ads/googleads/v8/services/services/video_service/transports/*',
                  'ads/googleads/v8/services/services/webpage_view_service/*',
                  'ads/googleads/v8/services/services/webpage_view_service/transports/*',
                  'ads/googleads/v8/services/types/*',
                  'ads/googleads/v8/types/*']}

install_requires = \
['google-ads>=14.0.0,<15.0.0',
 'google-auth-stubs>=0.1.0,<0.2.0',
 'googleapis-common-protos-stubs>=2.0.0,<3.0.0',
 'grpc-stubs>=1.24.7,<2.0.0',
 'proto-plus-stubs>=0.1.0,<0.2.0',
 'types-protobuf>=3.18.0,<4.0.0',
 'typing-extensions>=3.10.0,<4.0.0']

setup_kwargs = {
    'name': 'google-ads-stubs',
    'version': '8.0.0',
    'description': 'Type stubs for google-ads',
    'long_description': "# Type stubs for the Google Ads API Client Library for Python\n\n[![PyPI version](https://badge.fury.io/py/google-ads-stubs.svg)](https://badge.fury.io/py/google-ads-stubs)\n\nThis package provides type stubs for the [Google Ads API Client Library for Python](https://github.com/googleads/google-ads-python). \nIt's currently compatible with v14.0.0 of this library. It allows you to type check usage of the library with e.g. [mypy](http://mypy-lang.org/) and will also improve autocomplete in many editors.\n\n**This is in no way affiliated with Google.**\n\nMost stubs were created automatically by [stubgen](https://mypy.readthedocs.io/en/stable/stubgen.html), the rest are handwritten or generated by self-made scripts.\n\nIf you find incorrect annotations, please create an issue. Contributions for fixes are also welcome.\n\n## Installation\n\n```\n$ pip install google-ads-stubs\n```\n\n## Caveats\n\nThere are some caveats. The primary one is that type inference does _not_ work for the `get_type` and `get_service`\nmethods of `Client`. The workaround is to explicitly state the type. For `get_type` you can also instantiate\nthe object directly.\n\n```python\n# Replace this:\ncampaign_operation = client.get_type('CampaignOperation')\n# With this:\nfrom google.ads.googleads.v8 import CampaignOperation\ncampaign_operation: CampaignOperation = client.get_type('CampaignOperation')\n# Or this:\nfrom google.ads.googleads.v8 import CampaignOperation\ncampaign_operation = CampaignOperation()\n\n# Replace this:\ngoogle_ads_service = client.get_service('GoogleAdsService')\n# With this:\nfrom google.ads.googleads.v8 import GoogleAdsServiceClient\ngoogle_ads_service: GoogleAdsServiceClient = client.get_service('GoogleAdsService')\n```\n\nWhile it is technically possible to type these methods using a combination of overloading and literal types,\nthis is not included in these stubs. The reason is that it requires about 10,000 overloads, which makes most typecheckers fairly slow.\n\nAnother big caveat since v8.0.0 of this package is that the attributes and constructor arguments of the protobuf messages are all typed as `Any` instead of their proper types. This is due to `google-ads-python` switching from raw protobuf message classes to `proto-plus` classes. Better types for these might be introduced in the future. `GoogleAdsClient.enums` is also typed as `Any`.\n\n\nNote that if you're using Mypy you need to use the `--namespace-packages` option as `google` and `google.ads` are namespace packages.",
    'author': 'Henrik Bruåsdal',
    'author_email': 'henrik.bruasdal@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/henribru/google-ads-stubs',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)



from typing import Any

import proto
from google.protobuf import field_mask_pb2 as field_mask_pb2
from google.rpc import status_pb2 as status_pb2

from google.ads.googleads.v8.common.types import policy as policy

__protobuf__: Any

class GetAdRequest(proto.Message):
    resource_name: Any

class MutateAdsRequest(proto.Message):
    customer_id: Any
    operations: Any
    partial_failure: Any
    response_content_type: Any
    validate_only: Any

class AdOperation(proto.Message):
    update_mask: Any
    policy_validation_parameter: Any
    update: Any

class MutateAdsResponse(proto.Message):
    partial_failure_error: Any
    results: Any

class MutateAdResult(proto.Message):
    resource_name: Any
    ad: Any



from typing import Any

import proto

__protobuf__: Any

class AccessInvitationErrorEnum(proto.Message):
    class AccessInvitationError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        INVALID_EMAIL_ADDRESS: int
        EMAIL_ADDRESS_ALREADY_HAS_ACCESS: int
        INVALID_INVITATION_STATUS: int
        GOOGLE_CONSUMER_ACCOUNT_NOT_ALLOWED: int
        INVALID_INVITATION_ID: int
        EMAIL_ADDRESS_ALREADY_HAS_PENDING_INVITATION: int
        PENDING_INVITATIONS_LIMIT_EXCEEDED: int
        EMAIL_DOMAIN_POLICY_VIOLATED: int



from typing import Any

import proto

__protobuf__: Any

class ResourceAccessDeniedErrorEnum(proto.Message):
    class ResourceAccessDeniedError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        WRITE_ACCESS_DENIED: int



from typing import Any

import proto

__protobuf__: Any

class GenderTypeEnum(proto.Message):
    class GenderType(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        MALE: int
        FEMALE: int
        UNDETERMINED: int



from typing import Any

import proto

__protobuf__: Any

class ListingGroupTypeEnum(proto.Message):
    class ListingGroupType(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        SUBDIVISION: int
        UNIT: int



from typing import Any

import proto

__protobuf__: Any

class OfflineUserDataJobFailureReasonEnum(proto.Message):
    class OfflineUserDataJobFailureReason(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        INSUFFICIENT_MATCHED_TRANSACTIONS: int
        INSUFFICIENT_TRANSACTIONS: int



from typing import Any

import proto

from google.ads.googleads.v7.common.types import (
    custom_parameter as custom_parameter,
    feed_common as feed_common,
)
from google.ads.googleads.v7.enums.types import (
    feed_item_quality_approval_status as feed_item_quality_approval_status,
    feed_item_quality_disapproval_reason as feed_item_quality_disapproval_reason,
    feed_item_status as feed_item_status,
    feed_item_validation_status as feed_item_validation_status,
    placeholder_type as placeholder_type,
    policy_approval_status as policy_approval_status,
    policy_review_status as policy_review_status,
)
from google.ads.googleads.v7.errors.types import (
    feed_item_validation_error as feed_item_validation_error,
)

__protobuf__: Any

class FeedItem(proto.Message):
    resource_name: Any
    feed: Any
    id: Any
    start_date_time: Any
    end_date_time: Any
    attribute_values: Any
    geo_targeting_restriction: Any
    url_custom_parameters: Any
    status: Any
    policy_infos: Any

class FeedItemAttributeValue(proto.Message):
    feed_attribute_id: Any
    integer_value: Any
    boolean_value: Any
    string_value: Any
    double_value: Any
    price_value: Any
    integer_values: Any
    boolean_values: Any
    string_values: Any
    double_values: Any

class FeedItemPlaceholderPolicyInfo(proto.Message):
    placeholder_type_enum: Any
    feed_mapping_resource_name: Any
    review_status: Any
    approval_status: Any
    policy_topic_entries: Any
    validation_status: Any
    validation_errors: Any
    quality_approval_status: Any
    quality_disapproval_reasons: Any

class FeedItemValidationError(proto.Message):
    validation_error: Any
    description: Any
    feed_attribute_ids: Any
    extra_info: Any



from typing import Any

import proto

__protobuf__: Any

class AdvertisingChannelTypeEnum(proto.Message):
    class AdvertisingChannelType(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        SEARCH: int
        DISPLAY: int
        SHOPPING: int
        HOTEL: int
        VIDEO: int
        MULTI_CHANNEL: int
        LOCAL: int
        SMART: int



import abc
import typing
from typing import Any

from google.api_core import gapic_v1
from google.auth import credentials as ga_credentials

from google.ads.googleads.v8.resources.types import customer_user_access
from google.ads.googleads.v8.services.types import customer_user_access_service

class CustomerUserAccessServiceTransport(metaclass=abc.ABCMeta):
    AUTH_SCOPES: Any
    def __init__(
        self,
        *,
        host: str = ...,
        credentials: ga_credentials.Credentials = ...,
        client_info: gapic_v1.client_info.ClientInfo = ...
    ) -> None: ...
    @property
    def get_customer_user_access(
        self,
    ) -> typing.Callable[
        [customer_user_access_service.GetCustomerUserAccessRequest],
        customer_user_access.CustomerUserAccess,
    ]: ...
    @property
    def mutate_customer_user_access(
        self,
    ) -> typing.Callable[
        [customer_user_access_service.MutateCustomerUserAccessRequest],
        customer_user_access_service.MutateCustomerUserAccessResponse,
    ]: ...



from typing import Any

import proto

__protobuf__: Any

class AdGroupCriterionApprovalStatusEnum(proto.Message):
    class AdGroupCriterionApprovalStatus(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        APPROVED: int
        DISAPPROVED: int
        PENDING_REVIEW: int
        UNDER_REVIEW: int



from typing import Any

import proto

__protobuf__: Any

class ProductChannelEnum(proto.Message):
    class ProductChannel(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        ONLINE: int
        LOCAL: int



from typing import Any

import proto

__protobuf__: Any

class OfflineUserDataJobErrorEnum(proto.Message):
    class OfflineUserDataJobError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        INVALID_USER_LIST_ID: int
        INVALID_USER_LIST_TYPE: int
        NOT_ON_ALLOWLIST_FOR_USER_ID: int
        INCOMPATIBLE_UPLOAD_KEY_TYPE: int
        MISSING_USER_IDENTIFIER: int
        INVALID_MOBILE_ID_FORMAT: int
        TOO_MANY_USER_IDENTIFIERS: int
        NOT_ON_ALLOWLIST_FOR_STORE_SALES_DIRECT: int
        NOT_ON_ALLOWLIST_FOR_UNIFIED_STORE_SALES: int
        INVALID_PARTNER_ID: int
        INVALID_ENCODING: int
        INVALID_COUNTRY_CODE: int
        INCOMPATIBLE_USER_IDENTIFIER: int
        FUTURE_TRANSACTION_TIME: int
        INVALID_CONVERSION_ACTION: int
        MOBILE_ID_NOT_SUPPORTED: int
        INVALID_OPERATION_ORDER: int
        CONFLICTING_OPERATION: int
        EXTERNAL_UPDATE_ID_ALREADY_EXISTS: int
        JOB_ALREADY_STARTED: int
        REMOVE_NOT_SUPPORTED: int
        REMOVE_ALL_NOT_SUPPORTED: int
        INVALID_SHA256_FORMAT: int
        CUSTOM_KEY_DISABLED: int
        CUSTOM_KEY_NOT_PREDEFINED: int
        CUSTOM_KEY_NOT_SET: int
        CUSTOMER_NOT_ACCEPTED_CUSTOMER_DATA_TERMS: int
        ATTRIBUTES_NOT_APPLICABLE_FOR_CUSTOMER_MATCH_USER_LIST: int
        LIFETIME_VALUE_BUCKET_NOT_IN_RANGE: int
        INCOMPATIBLE_USER_IDENTIFIER_FOR_ATTRIBUTES: int



from typing import Any

import proto

__protobuf__: Any

class BiddingSourceEnum(proto.Message):
    class BiddingSource(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        CAMPAIGN_BIDDING_STRATEGY: int
        AD_GROUP: int
        AD_GROUP_CRITERION: int



from typing import Any

import proto

__protobuf__: Any

class PaymentsAccountErrorEnum(proto.Message):
    class PaymentsAccountError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        NOT_SUPPORTED_FOR_MANAGER_CUSTOMER: int



from typing import Any

import proto

__protobuf__: Any

class AccessInvitationStatusEnum(proto.Message):
    class AccessInvitationStatus(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        PENDING: int
        DECLINED: int
        EXPIRED: int



from typing import Any

import proto

__protobuf__: Any

class DetailPlacementView(proto.Message):
    resource_name: Any
    placement: Any
    display_name: Any
    group_placement_target_url: Any
    target_url: Any
    placement_type: Any



from typing import Any

import proto

__protobuf__: Any

class AccountBudgetProposalErrorEnum(proto.Message):
    class AccountBudgetProposalError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        FIELD_MASK_NOT_ALLOWED: int
        IMMUTABLE_FIELD: int
        REQUIRED_FIELD_MISSING: int
        CANNOT_CANCEL_APPROVED_PROPOSAL: int
        CANNOT_REMOVE_UNAPPROVED_BUDGET: int
        CANNOT_REMOVE_RUNNING_BUDGET: int
        CANNOT_END_UNAPPROVED_BUDGET: int
        CANNOT_END_INACTIVE_BUDGET: int
        BUDGET_NAME_REQUIRED: int
        CANNOT_UPDATE_OLD_BUDGET: int
        CANNOT_END_IN_PAST: int
        CANNOT_EXTEND_END_TIME: int
        PURCHASE_ORDER_NUMBER_REQUIRED: int
        PENDING_UPDATE_PROPOSAL_EXISTS: int
        MULTIPLE_BUDGETS_NOT_ALLOWED_FOR_UNAPPROVED_BILLING_SETUP: int
        CANNOT_UPDATE_START_TIME_FOR_STARTED_BUDGET: int
        SPENDING_LIMIT_LOWER_THAN_ACCRUED_COST_NOT_ALLOWED: int
        UPDATE_IS_NO_OP: int
        END_TIME_MUST_FOLLOW_START_TIME: int
        BUDGET_DATE_RANGE_INCOMPATIBLE_WITH_BILLING_SETUP: int
        NOT_AUTHORIZED: int
        INVALID_BILLING_SETUP: int
        OVERLAPS_EXISTING_BUDGET: int
        CANNOT_CREATE_BUDGET_THROUGH_API: int



from typing import Any

import proto

from google.ads.googleads.v7.enums.types import (
    ad_group_ad_status as ad_group_ad_status,
    policy_approval_status as policy_approval_status,
    policy_review_status as policy_review_status,
)

__protobuf__: Any

class AdGroupAd(proto.Message):
    resource_name: Any
    status: Any
    ad_group: Any
    ad: Any
    policy_summary: Any
    ad_strength: Any
    labels: Any

class AdGroupAdPolicySummary(proto.Message):
    policy_topic_entries: Any
    review_status: Any
    approval_status: Any



from typing import Any

import proto
from google.rpc import status_pb2 as status_pb2

__protobuf__: Any

class GetFeedItemTargetRequest(proto.Message):
    resource_name: Any

class MutateFeedItemTargetsRequest(proto.Message):
    customer_id: Any
    operations: Any
    partial_failure: Any
    response_content_type: Any
    validate_only: Any

class FeedItemTargetOperation(proto.Message):
    create: Any
    remove: Any

class MutateFeedItemTargetsResponse(proto.Message):
    partial_failure_error: Any
    results: Any

class MutateFeedItemTargetResult(proto.Message):
    resource_name: Any
    feed_item_target: Any



from typing import Any

import proto

from google.ads.googleads.v8.enums.types import (
    bidding_strategy_type as bidding_strategy_type,
    target_impression_share_location as target_impression_share_location,
)

__protobuf__: Any

class AccessibleBiddingStrategy(proto.Message):
    class MaximizeConversionValue(proto.Message):
        target_roas: Any
    class MaximizeConversions(proto.Message):
        target_cpa: Any
    class TargetCpa(proto.Message):
        target_cpa_micros: Any
    class TargetSpend(proto.Message):
        target_spend_micros: Any
        cpc_bid_ceiling_micros: Any
    class TargetImpressionShare(proto.Message):
        location: Any
        location_fraction_micros: Any
        cpc_bid_ceiling_micros: Any
    class TargetRoas(proto.Message):
        target_roas: Any
    resource_name: Any
    id: Any
    name: Any
    type_: Any
    owner_customer_id: Any
    owner_descriptive_name: Any
    maximize_conversion_value: Any
    maximize_conversions: Any
    target_cpa: Any
    target_impression_share: Any
    target_roas: Any
    target_spend: Any



from typing import Any

import proto

__protobuf__: Any

class ImageErrorEnum(proto.Message):
    class ImageError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        INVALID_IMAGE: int
        STORAGE_ERROR: int
        BAD_REQUEST: int
        UNEXPECTED_SIZE: int
        ANIMATED_NOT_ALLOWED: int
        ANIMATION_TOO_LONG: int
        SERVER_ERROR: int
        CMYK_JPEG_NOT_ALLOWED: int
        FLASH_NOT_ALLOWED: int
        FLASH_WITHOUT_CLICKTAG: int
        FLASH_ERROR_AFTER_FIXING_CLICK_TAG: int
        ANIMATED_VISUAL_EFFECT: int
        FLASH_ERROR: int
        LAYOUT_PROBLEM: int
        PROBLEM_READING_IMAGE_FILE: int
        ERROR_STORING_IMAGE: int
        ASPECT_RATIO_NOT_ALLOWED: int
        FLASH_HAS_NETWORK_OBJECTS: int
        FLASH_HAS_NETWORK_METHODS: int
        FLASH_HAS_URL: int
        FLASH_HAS_MOUSE_TRACKING: int
        FLASH_HAS_RANDOM_NUM: int
        FLASH_SELF_TARGETS: int
        FLASH_BAD_GETURL_TARGET: int
        FLASH_VERSION_NOT_SUPPORTED: int
        FLASH_WITHOUT_HARD_CODED_CLICK_URL: int
        INVALID_FLASH_FILE: int
        FAILED_TO_FIX_CLICK_TAG_IN_FLASH: int
        FLASH_ACCESSES_NETWORK_RESOURCES: int
        FLASH_EXTERNAL_JS_CALL: int
        FLASH_EXTERNAL_FS_CALL: int
        FILE_TOO_LARGE: int
        IMAGE_DATA_TOO_LARGE: int
        IMAGE_PROCESSING_ERROR: int
        IMAGE_TOO_SMALL: int
        INVALID_INPUT: int
        PROBLEM_READING_FILE: int
        IMAGE_CONSTRAINTS_VIOLATED: int
        FORMAT_NOT_ALLOWED: int



from .base import (
    AdGroupExtensionSettingServiceTransport as AdGroupExtensionSettingServiceTransport,
)
from .grpc import (
    AdGroupExtensionSettingServiceGrpcTransport as AdGroupExtensionSettingServiceGrpcTransport,
)



from typing import Any

import proto

__protobuf__: Any

class GoogleAdsFieldCategoryEnum(proto.Message):
    class GoogleAdsFieldCategory(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        RESOURCE: int
        ATTRIBUTE: int
        SEGMENT: int
        METRIC: int



from typing import Any

import proto

__protobuf__: Any

class JobPlaceholderFieldEnum(proto.Message):
    class JobPlaceholderField(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        JOB_ID: int
        LOCATION_ID: int
        TITLE: int
        SUBTITLE: int
        DESCRIPTION: int
        IMAGE_URL: int
        CATEGORY: int
        CONTEXTUAL_KEYWORDS: int
        ADDRESS: int
        SALARY: int
        FINAL_URLS: int
        FINAL_MOBILE_URLS: int
        TRACKING_URL: int
        ANDROID_APP_LINK: int
        SIMILAR_JOB_IDS: int
        IOS_APP_LINK: int
        IOS_APP_STORE_ID: int



from typing import Any

import proto

__protobuf__: Any

class ManagerLinkStatusEnum(proto.Message):
    class ManagerLinkStatus(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        ACTIVE: int
        INACTIVE: int
        PENDING: int
        REFUSED: int
        CANCELED: int



from typing import Any

import proto

__protobuf__: Any

class ConversionActionCategoryEnum(proto.Message):
    class ConversionActionCategory(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        DEFAULT: int
        PAGE_VIEW: int
        PURCHASE: int
        SIGNUP: int
        LEAD: int
        DOWNLOAD: int
        ADD_TO_CART: int
        BEGIN_CHECKOUT: int
        SUBSCRIBE_PAID: int
        PHONE_CALL_LEAD: int
        IMPORTED_LEAD: int
        SUBMIT_LEAD_FORM: int
        BOOK_APPOINTMENT: int
        REQUEST_QUOTE: int
        GET_DIRECTIONS: int
        OUTBOUND_CLICK: int
        CONTACT: int
        ENGAGEMENT: int
        STORE_VISIT: int
        STORE_SALE: int



from typing import Any

import proto

__protobuf__: Any

class AuthorizationErrorEnum(proto.Message):
    class AuthorizationError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        USER_PERMISSION_DENIED: int
        DEVELOPER_TOKEN_NOT_ON_ALLOWLIST: int
        DEVELOPER_TOKEN_PROHIBITED: int
        PROJECT_DISABLED: int
        AUTHORIZATION_ERROR: int
        ACTION_NOT_PERMITTED: int
        INCOMPLETE_SIGNUP: int
        CUSTOMER_NOT_ENABLED: int
        MISSING_TOS: int
        DEVELOPER_TOKEN_NOT_APPROVED: int
        INVALID_LOGIN_CUSTOMER_ID_SERVING_CUSTOMER_ID_COMBINATION: int
        SERVICE_ACCESS_DENIED: int
        ACCESS_DENIED_FOR_ACCOUNT_TYPE: int



from typing import Any

import proto

__protobuf__: Any

class InteractionEventTypeEnum(proto.Message):
    class InteractionEventType(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        CLICK: int
        ENGAGEMENT: int
        VIDEO_VIEW: int
        NONE: int



from typing import Any

import proto
from google.rpc import status_pb2 as status_pb2

from google.ads.googleads.v8.resources.types import (
    ad_group_ad_label as ad_group_ad_label,
)

__protobuf__: Any

class GetAdGroupAdLabelRequest(proto.Message):
    resource_name: Any

class MutateAdGroupAdLabelsRequest(proto.Message):
    customer_id: Any
    operations: Any
    partial_failure: Any
    validate_only: Any

class AdGroupAdLabelOperation(proto.Message):
    create: Any
    remove: Any

class MutateAdGroupAdLabelsResponse(proto.Message):
    partial_failure_error: Any
    results: Any

class MutateAdGroupAdLabelResult(proto.Message):
    resource_name: Any



from typing import Any

import proto

from google.ads.googleads.v7.enums.types import (
    conversion_adjustment_type as conversion_adjustment_type,
)

__protobuf__: Any

class UploadConversionAdjustmentsRequest(proto.Message):
    customer_id: Any
    conversion_adjustments: Any
    partial_failure: Any
    validate_only: Any

class UploadConversionAdjustmentsResponse(proto.Message):
    partial_failure_error: Any
    results: Any

class ConversionAdjustment(proto.Message):
    conversion_action: Any
    adjustment_date_time: Any
    adjustment_type: Any
    restatement_value: Any
    gclid_date_time_pair: Any
    order_id: Any

class RestatementValue(proto.Message):
    adjusted_value: Any
    currency_code: Any

class GclidDateTimePair(proto.Message):
    gclid: Any
    conversion_date_time: Any

class ConversionAdjustmentResult(proto.Message):
    conversion_action: Any
    adjustment_date_time: Any
    adjustment_type: Any
    gclid_date_time_pair: Any
    order_id: Any



from typing import Any

import proto
from google.rpc import status_pb2 as status_pb2

from google.ads.googleads.v8.resources.types import batch_job as batch_job
from google.ads.googleads.v8.services.types import (
    google_ads_service as google_ads_service,
)

__protobuf__: Any

class MutateBatchJobRequest(proto.Message):
    customer_id: Any
    operation: Any

class BatchJobOperation(proto.Message):
    create: Any

class MutateBatchJobResponse(proto.Message):
    result: Any

class MutateBatchJobResult(proto.Message):
    resource_name: Any

class GetBatchJobRequest(proto.Message):
    resource_name: Any

class RunBatchJobRequest(proto.Message):
    resource_name: Any

class AddBatchJobOperationsRequest(proto.Message):
    resource_name: Any
    sequence_token: Any
    mutate_operations: Any

class AddBatchJobOperationsResponse(proto.Message):
    total_operations: Any
    next_sequence_token: Any

class ListBatchJobResultsRequest(proto.Message):
    resource_name: Any
    page_token: Any
    page_size: Any
    response_content_type: Any

class ListBatchJobResultsResponse(proto.Message):
    @property
    def raw_page(self): ...
    results: Any
    next_page_token: Any

class BatchJobResult(proto.Message):
    operation_index: Any
    mutate_operation_response: Any
    status: Any



from typing import Any

import proto

__protobuf__: Any

class ChangeStatusResourceTypeEnum(proto.Message):
    class ChangeStatusResourceType(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        AD_GROUP: int
        AD_GROUP_AD: int
        AD_GROUP_CRITERION: int
        CAMPAIGN: int
        CAMPAIGN_CRITERION: int
        FEED: int
        FEED_ITEM: int
        AD_GROUP_FEED: int
        CAMPAIGN_FEED: int
        AD_GROUP_BID_MODIFIER: int
        SHARED_SET: int
        CAMPAIGN_SHARED_SET: int
        ASSET: int
        CUSTOMER_ASSET: int
        CAMPAIGN_ASSET: int
        AD_GROUP_ASSET: int



from typing import Any

import proto

__protobuf__: Any

class AppPaymentModelTypeEnum(proto.Message):
    class AppPaymentModelType(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        PAID: int



from typing import Any

import proto

__protobuf__: Any

class FeedMappingCriterionTypeEnum(proto.Message):
    class FeedMappingCriterionType(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        LOCATION_EXTENSION_TARGETING: int
        DSA_PAGE_FEED: int



from typing import Any

import proto

__protobuf__: Any

class GetGeoTargetConstantRequest(proto.Message):
    resource_name: Any

class SuggestGeoTargetConstantsRequest(proto.Message):
    class LocationNames(proto.Message):
        names: Any
    class GeoTargets(proto.Message):
        geo_target_constants: Any
    locale: Any
    country_code: Any
    location_names: Any
    geo_targets: Any

class SuggestGeoTargetConstantsResponse(proto.Message):
    geo_target_constant_suggestions: Any

class GeoTargetConstantSuggestion(proto.Message):
    locale: Any
    reach: Any
    search_term: Any
    geo_target_constant: Any
    geo_target_constant_parents: Any



import abc
import typing
from typing import Any

from google.api_core import gapic_v1
from google.auth import credentials

from google.ads.googleads.v7.resources.types import label
from google.ads.googleads.v7.services.types import label_service

class LabelServiceTransport(metaclass=abc.ABCMeta):
    AUTH_SCOPES: Any
    def __init__(
        self,
        *,
        host: str = ...,
        credentials: credentials.Credentials = ...,
        client_info: gapic_v1.client_info.ClientInfo = ...
    ) -> None: ...
    @property
    def get_label(
        self,
    ) -> typing.Callable[[label_service.GetLabelRequest], label.Label]: ...
    @property
    def mutate_labels(
        self,
    ) -> typing.Callable[
        [label_service.MutateLabelsRequest], label_service.MutateLabelsResponse
    ]: ...



from typing import Any

import proto

__protobuf__: Any

class CustomerUserAccessErrorEnum(proto.Message):
    class CustomerUserAccessError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        INVALID_USER_ID: int
        REMOVAL_DISALLOWED: int
        DISALLOWED_ACCESS_ROLE: int
        LAST_ADMIN_USER_OF_SERVING_CUSTOMER: int
        LAST_ADMIN_USER_OF_MANAGER: int



from typing import Any

import proto

__protobuf__: Any

class InvoiceErrorEnum(proto.Message):
    class InvoiceError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        YEAR_MONTH_TOO_OLD: int
        NOT_INVOICED_CUSTOMER: int
        BILLING_SETUP_NOT_APPROVED: int



from typing import Any

import proto

from google.ads.googleads.v7.common.types import criteria as criteria
from google.ads.googleads.v7.enums.types import (
    campaign_criterion_status as campaign_criterion_status,
    criterion_type as criterion_type,
)

__protobuf__: Any

class CampaignCriterion(proto.Message):
    resource_name: Any
    campaign: Any
    criterion_id: Any
    display_name: Any
    bid_modifier: Any
    negative: Any
    type_: Any
    status: Any
    keyword: Any
    placement: Any
    mobile_app_category: Any
    mobile_application: Any
    location: Any
    device: Any
    ad_schedule: Any
    age_range: Any
    gender: Any
    income_range: Any
    parental_status: Any
    user_list: Any
    youtube_video: Any
    youtube_channel: Any
    proximity: Any
    topic: Any
    listing_scope: Any
    language: Any
    ip_block: Any
    content_label: Any
    carrier: Any
    user_interest: Any
    webpage: Any
    operating_system_version: Any
    mobile_device: Any
    location_group: Any
    custom_affinity: Any
    custom_audience: Any
    combined_audience: Any



from typing import Any

import proto

__protobuf__: Any

class BiddingStrategyTypeEnum(proto.Message):
    class BiddingStrategyType(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        COMMISSION: int
        ENHANCED_CPC: int
        INVALID: int
        MANUAL_CPC: int
        MANUAL_CPM: int
        MANUAL_CPV: int
        MAXIMIZE_CONVERSIONS: int
        MAXIMIZE_CONVERSION_VALUE: int
        PAGE_ONE_PROMOTED: int
        PERCENT_CPC: int
        TARGET_CPA: int
        TARGET_CPM: int
        TARGET_IMPRESSION_SHARE: int
        TARGET_OUTRANK_SHARE: int
        TARGET_ROAS: int
        TARGET_SPEND: int



from typing import Any

import proto

__protobuf__: Any

class HotelDateSelectionTypeEnum(proto.Message):
    class HotelDateSelectionType(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        DEFAULT_SELECTION: int
        USER_SELECTED: int



from typing import Any

import proto

__protobuf__: Any

class AdParameterErrorEnum(proto.Message):
    class AdParameterError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        AD_GROUP_CRITERION_MUST_BE_KEYWORD: int
        INVALID_INSERTION_TEXT_FORMAT: int



from typing import Any

import proto

from google.ads.googleads.v7.enums.types import (
    criterion_category_channel_availability_mode as criterion_category_channel_availability_mode,
    criterion_category_locale_availability_mode as criterion_category_locale_availability_mode,
)

__protobuf__: Any

class CriterionCategoryAvailability(proto.Message):
    channel: Any
    locale: Any

class CriterionCategoryChannelAvailability(proto.Message):
    availability_mode: Any
    advertising_channel_type: Any
    advertising_channel_sub_type: Any
    include_default_channel_sub_type: Any

class CriterionCategoryLocaleAvailability(proto.Message):
    availability_mode: Any
    country_code: Any
    language_code: Any



from typing import Any

import proto

from google.ads.googleads.v8.enums.types import (
    combined_audience_status as combined_audience_status,
)

__protobuf__: Any

class CombinedAudience(proto.Message):
    resource_name: Any
    id: Any
    status: Any
    name: Any
    description: Any



from typing import Any

import proto

__protobuf__: Any

class KeywordPlanIdeaErrorEnum(proto.Message):
    class KeywordPlanIdeaError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        URL_CRAWL_ERROR: int
        INVALID_VALUE: int



from .base import (
    CampaignAudienceViewServiceTransport as CampaignAudienceViewServiceTransport,
)
from .grpc import (
    CampaignAudienceViewServiceGrpcTransport as CampaignAudienceViewServiceGrpcTransport,
)



from typing import Any

import proto

__protobuf__: Any

class SmartCampaignSetting(proto.Message):
    class PhoneNumber(proto.Message):
        phone_number: Any
        country_code: Any
    resource_name: Any
    campaign: Any
    phone_number: Any
    final_url: Any
    advertising_language_code: Any
    business_name: Any
    business_location_id: Any



from typing import Any

import proto

__protobuf__: Any

class FeedItemSetLinkErrorEnum(proto.Message):
    class FeedItemSetLinkError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        FEED_ID_MISMATCH: int
        NO_MUTATE_ALLOWED_FOR_DYNAMIC_SET: int



from typing import Any

import proto

__protobuf__: Any

class MultiplierErrorEnum(proto.Message):
    class MultiplierError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        MULTIPLIER_TOO_HIGH: int
        MULTIPLIER_TOO_LOW: int
        TOO_MANY_FRACTIONAL_DIGITS: int
        MULTIPLIER_NOT_ALLOWED_FOR_BIDDING_STRATEGY: int
        MULTIPLIER_NOT_ALLOWED_WHEN_BASE_BID_IS_MISSING: int
        NO_MULTIPLIER_SPECIFIED: int
        MULTIPLIER_CAUSES_BID_TO_EXCEED_DAILY_BUDGET: int
        MULTIPLIER_CAUSES_BID_TO_EXCEED_MONTHLY_BUDGET: int
        MULTIPLIER_CAUSES_BID_TO_EXCEED_CUSTOM_BUDGET: int
        MULTIPLIER_CAUSES_BID_TO_EXCEED_MAX_ALLOWED_BID: int
        BID_LESS_THAN_MIN_ALLOWED_BID_WITH_MULTIPLIER: int
        MULTIPLIER_AND_BIDDING_STRATEGY_TYPE_MISMATCH: int



from typing import Any

import proto

__protobuf__: Any

class GroupPlacementView(proto.Message):
    resource_name: Any
    placement: Any
    display_name: Any
    target_url: Any
    placement_type: Any



from typing import Any

import proto

__protobuf__: Any

class ConversionUploadErrorEnum(proto.Message):
    class ConversionUploadError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        TOO_MANY_CONVERSIONS_IN_REQUEST: int
        UNPARSEABLE_GCLID: int
        CONVERSION_PRECEDES_GCLID: int
        EXPIRED_GCLID: int
        TOO_RECENT_GCLID: int
        GCLID_NOT_FOUND: int
        UNAUTHORIZED_CUSTOMER: int
        INVALID_CONVERSION_ACTION: int
        TOO_RECENT_CONVERSION_ACTION: int
        CONVERSION_TRACKING_NOT_ENABLED_AT_IMPRESSION_TIME: int
        EXTERNAL_ATTRIBUTION_DATA_SET_FOR_NON_EXTERNALLY_ATTRIBUTED_CONVERSION_ACTION: int
        EXTERNAL_ATTRIBUTION_DATA_NOT_SET_FOR_EXTERNALLY_ATTRIBUTED_CONVERSION_ACTION: int
        ORDER_ID_NOT_PERMITTED_FOR_EXTERNALLY_ATTRIBUTED_CONVERSION_ACTION: int
        ORDER_ID_ALREADY_IN_USE: int
        DUPLICATE_ORDER_ID: int
        TOO_RECENT_CALL: int
        EXPIRED_CALL: int
        CALL_NOT_FOUND: int
        CONVERSION_PRECEDES_CALL: int
        CONVERSION_TRACKING_NOT_ENABLED_AT_CALL_TIME: int
        UNPARSEABLE_CALLERS_PHONE_NUMBER: int
        CUSTOM_VARIABLE_NOT_ENABLED: int
        CUSTOM_VARIABLE_VALUE_CONTAINS_PII: int
        INVALID_CUSTOMER_FOR_CLICK: int
        INVALID_CUSTOMER_FOR_CALL: int
        CONVERSION_NOT_COMPLIANT_WITH_ATT_POLICY: int
        CLICK_NOT_FOUND: int
        INVALID_USER_IDENTIFIER: int
        EXTERNALLY_ATTRIBUTED_CONVERSION_ACTION_NOT_PERMITTED_WITH_USER_IDENTIFIER: int
        UNSUPPORTED_USER_IDENTIFIER: int
        INVALID_USER_IDENTIFIER_SOURCE: int



from typing import Any

import proto

from google.ads.googleads.v7.common.types import custom_parameter as custom_parameter
from google.ads.googleads.v7.enums.types import (
    ad_group_ad_rotation_mode as ad_group_ad_rotation_mode,
    ad_group_status as ad_group_status,
    ad_group_type as ad_group_type,
    asset_field_type as asset_field_type,
    bidding_source as bidding_source,
    targeting_dimension as targeting_dimension,
)

__protobuf__: Any

class AdGroup(proto.Message):
    resource_name: Any
    id: Any
    name: Any
    status: Any
    type_: Any
    ad_rotation_mode: Any
    base_ad_group: Any
    tracking_url_template: Any
    url_custom_parameters: Any
    campaign: Any
    cpc_bid_micros: Any
    cpm_bid_micros: Any
    target_cpa_micros: Any
    cpv_bid_micros: Any
    target_cpm_micros: Any
    target_roas: Any
    percent_cpc_bid_micros: Any
    explorer_auto_optimizer_setting: Any
    display_custom_bid_dimension: Any
    final_url_suffix: Any
    targeting_setting: Any
    effective_target_cpa_micros: Any
    effective_target_cpa_source: Any
    effective_target_roas: Any
    effective_target_roas_source: Any
    labels: Any
    excluded_parent_asset_field_types: Any



from typing import Any

import proto

from google.ads.googleads.v7.common.types import (
    click_location as click_location,
    criteria as criteria,
)

__protobuf__: Any

class ClickView(proto.Message):
    resource_name: Any
    gclid: Any
    area_of_interest: Any
    location_of_presence: Any
    page_number: Any
    ad_group_ad: Any
    campaign_location_target: Any
    user_list: Any
    keyword: Any
    keyword_info: Any



from typing import Any

import proto

__protobuf__: Any

class AccountBudgetProposalStatusEnum(proto.Message):
    class AccountBudgetProposalStatus(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        PENDING: int
        APPROVED_HELD: int
        APPROVED: int
        CANCELLED: int
        REJECTED: int



from typing import Any

import proto

from google.ads.googleads.v8.enums.types import (
    operating_system_version_operator_type as operating_system_version_operator_type,
)

__protobuf__: Any

class OperatingSystemVersionConstant(proto.Message):
    resource_name: Any
    id: Any
    name: Any
    os_major_version: Any
    os_minor_version: Any
    operator_type: Any



from typing import Any

import proto

__protobuf__: Any

class BidModifierSimulationPointList(proto.Message):
    points: Any

class CpcBidSimulationPointList(proto.Message):
    points: Any

class CpvBidSimulationPointList(proto.Message):
    points: Any

class TargetCpaSimulationPointList(proto.Message):
    points: Any

class TargetRoasSimulationPointList(proto.Message):
    points: Any

class PercentCpcBidSimulationPointList(proto.Message):
    points: Any

class BudgetSimulationPointList(proto.Message):
    points: Any

class TargetImpressionShareSimulationPointList(proto.Message):
    points: Any

class BidModifierSimulationPoint(proto.Message):
    bid_modifier: Any
    biddable_conversions: Any
    biddable_conversions_value: Any
    clicks: Any
    cost_micros: Any
    impressions: Any
    top_slot_impressions: Any
    parent_biddable_conversions: Any
    parent_biddable_conversions_value: Any
    parent_clicks: Any
    parent_cost_micros: Any
    parent_impressions: Any
    parent_top_slot_impressions: Any
    parent_required_budget_micros: Any

class CpcBidSimulationPoint(proto.Message):
    required_budget_amount_micros: Any
    biddable_conversions: Any
    biddable_conversions_value: Any
    clicks: Any
    cost_micros: Any
    impressions: Any
    top_slot_impressions: Any
    cpc_bid_micros: Any
    cpc_bid_scaling_modifier: Any

class CpvBidSimulationPoint(proto.Message):
    cpv_bid_micros: Any
    cost_micros: Any
    impressions: Any
    views: Any

class TargetCpaSimulationPoint(proto.Message):
    required_budget_amount_micros: Any
    biddable_conversions: Any
    biddable_conversions_value: Any
    app_installs: Any
    in_app_actions: Any
    clicks: Any
    cost_micros: Any
    impressions: Any
    top_slot_impressions: Any
    target_cpa_micros: Any
    target_cpa_scaling_modifier: Any

class TargetRoasSimulationPoint(proto.Message):
    target_roas: Any
    required_budget_amount_micros: Any
    biddable_conversions: Any
    biddable_conversions_value: Any
    clicks: Any
    cost_micros: Any
    impressions: Any
    top_slot_impressions: Any

class PercentCpcBidSimulationPoint(proto.Message):
    percent_cpc_bid_micros: Any
    biddable_conversions: Any
    biddable_conversions_value: Any
    clicks: Any
    cost_micros: Any
    impressions: Any
    top_slot_impressions: Any

class BudgetSimulationPoint(proto.Message):
    budget_amount_micros: Any
    required_cpc_bid_ceiling_micros: Any
    biddable_conversions: Any
    biddable_conversions_value: Any
    clicks: Any
    cost_micros: Any
    impressions: Any
    top_slot_impressions: Any

class TargetImpressionShareSimulationPoint(proto.Message):
    target_impression_share_micros: Any
    required_cpc_bid_ceiling_micros: Any
    required_budget_amount_micros: Any
    biddable_conversions: Any
    biddable_conversions_value: Any
    clicks: Any
    cost_micros: Any
    impressions: Any
    top_slot_impressions: Any
    absolute_top_impressions: Any



from typing import Any

import proto

__protobuf__: Any

class AppPlaceholderFieldEnum(proto.Message):
    class AppPlaceholderField(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        STORE: int
        ID: int
        LINK_TEXT: int
        URL: int
        FINAL_URLS: int
        FINAL_MOBILE_URLS: int
        TRACKING_URL: int
        FINAL_URL_SUFFIX: int



from typing import Any

import proto

__protobuf__: Any

class ValueRuleSetAttachmentTypeEnum(proto.Message):
    class ValueRuleSetAttachmentType(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        CUSTOMER: int
        CAMPAIGN: int



from typing import Any

import proto

from google.ads.googleads.v7.common.types import (
    criteria as criteria,
    feed_common as feed_common,
)
from google.ads.googleads.v7.enums.types import (
    lead_form_call_to_action_type as lead_form_call_to_action_type,
    lead_form_desired_intent as lead_form_desired_intent,
    lead_form_field_user_input_type as lead_form_field_user_input_type,
    lead_form_post_submit_call_to_action_type as lead_form_post_submit_call_to_action_type,
    promotion_extension_discount_modifier as promotion_extension_discount_modifier,
    promotion_extension_occasion as promotion_extension_occasion,
)

__protobuf__: Any

class YoutubeVideoAsset(proto.Message):
    youtube_video_id: Any
    youtube_video_title: Any

class MediaBundleAsset(proto.Message):
    data: Any

class ImageAsset(proto.Message):
    data: Any
    file_size: Any
    mime_type: Any
    full_size: Any

class ImageDimension(proto.Message):
    height_pixels: Any
    width_pixels: Any
    url: Any

class TextAsset(proto.Message):
    text: Any

class LeadFormAsset(proto.Message):
    business_name: Any
    call_to_action_type: Any
    call_to_action_description: Any
    headline: Any
    description: Any
    privacy_policy_url: Any
    post_submit_headline: Any
    post_submit_description: Any
    fields: Any
    delivery_methods: Any
    post_submit_call_to_action_type: Any
    background_image_asset: Any
    desired_intent: Any
    custom_disclosure: Any

class LeadFormField(proto.Message):
    input_type: Any
    single_choice_answers: Any

class LeadFormSingleChoiceAnswers(proto.Message):
    answers: Any

class LeadFormDeliveryMethod(proto.Message):
    webhook: Any

class WebhookDelivery(proto.Message):
    advertiser_webhook_url: Any
    google_secret: Any
    payload_schema_version: Any

class BookOnGoogleAsset(proto.Message): ...

class PromotionAsset(proto.Message):
    promotion_target: Any
    discount_modifier: Any
    redemption_start_date: Any
    redemption_end_date: Any
    occasion: Any
    language_code: Any
    start_date: Any
    end_date: Any
    ad_schedule_targets: Any
    percent_off: Any
    money_amount_off: Any
    promotion_code: Any
    orders_over_amount: Any

class CalloutAsset(proto.Message):
    callout_text: Any
    start_date: Any
    end_date: Any
    ad_schedule_targets: Any

class StructuredSnippetAsset(proto.Message):
    header: Any
    values: Any

class SitelinkAsset(proto.Message):
    link_text: Any
    description1: Any
    description2: Any
    start_date: Any
    end_date: Any
    ad_schedule_targets: Any



from typing import Any

import proto

__protobuf__: Any

class UserListPrepopulationStatusEnum(proto.Message):
    class UserListPrepopulationStatus(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        REQUESTED: int
        FINISHED: int
        FAILED: int



import abc
import typing
from typing import Any

from google.api_core import gapic_v1
from google.auth import credentials

from google.ads.googleads.v7.resources.types import third_party_app_analytics_link
from google.ads.googleads.v7.services.types import (
    third_party_app_analytics_link_service,
)

class ThirdPartyAppAnalyticsLinkServiceTransport(metaclass=abc.ABCMeta):
    AUTH_SCOPES: Any
    def __init__(
        self,
        *,
        host: str = ...,
        credentials: credentials.Credentials = ...,
        client_info: gapic_v1.client_info.ClientInfo = ...
    ) -> None: ...
    @property
    def get_third_party_app_analytics_link(
        self,
    ) -> typing.Callable[
        [third_party_app_analytics_link_service.GetThirdPartyAppAnalyticsLinkRequest],
        third_party_app_analytics_link.ThirdPartyAppAnalyticsLink,
    ]: ...
    @property
    def regenerate_shareable_link_id(
        self,
    ) -> typing.Callable[
        [third_party_app_analytics_link_service.RegenerateShareableLinkIdRequest],
        third_party_app_analytics_link_service.RegenerateShareableLinkIdResponse,
    ]: ...



from typing import Any

import proto

__protobuf__: Any

class WebpageConditionOperatorEnum(proto.Message):
    class WebpageConditionOperator(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        EQUALS: int
        CONTAINS: int



from typing import Any

import proto

__protobuf__: Any

class SlotEnum(proto.Message):
    class Slot(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        SEARCH_SIDE: int
        SEARCH_TOP: int
        SEARCH_OTHER: int
        CONTENT: int
        SEARCH_PARTNER_TOP: int
        SEARCH_PARTNER_OTHER: int
        MIXED: int



from typing import Any

import proto

__protobuf__: Any

class DistanceBucketEnum(proto.Message):
    class DistanceBucket(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        WITHIN_700M: int
        WITHIN_1KM: int
        WITHIN_5KM: int
        WITHIN_10KM: int
        WITHIN_15KM: int
        WITHIN_20KM: int
        WITHIN_25KM: int
        WITHIN_30KM: int
        WITHIN_35KM: int
        WITHIN_40KM: int
        WITHIN_45KM: int
        WITHIN_50KM: int
        WITHIN_55KM: int
        WITHIN_60KM: int
        WITHIN_65KM: int
        BEYOND_65KM: int
        WITHIN_0_7MILES: int
        WITHIN_1MILE: int
        WITHIN_5MILES: int
        WITHIN_10MILES: int
        WITHIN_15MILES: int
        WITHIN_20MILES: int
        WITHIN_25MILES: int
        WITHIN_30MILES: int
        WITHIN_35MILES: int
        WITHIN_40MILES: int
        BEYOND_40MILES: int



from typing import Any

import proto

__protobuf__: Any

class MutateErrorEnum(proto.Message):
    class MutateError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        RESOURCE_NOT_FOUND: int
        ID_EXISTS_IN_MULTIPLE_MUTATES: int
        INCONSISTENT_FIELD_VALUES: int
        MUTATE_NOT_ALLOWED: int
        RESOURCE_NOT_IN_GOOGLE_ADS: int
        RESOURCE_ALREADY_EXISTS: int
        RESOURCE_DOES_NOT_SUPPORT_VALIDATE_ONLY: int
        RESOURCE_READ_ONLY: int



from typing import Any

import proto

__protobuf__: Any

class LocationSourceTypeEnum(proto.Message):
    class LocationSourceType(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        GOOGLE_MY_BUSINESS: int
        AFFILIATE: int
